@@ -1,6 +1,6 @@
-# -*- coding: utf-8 -*-
+# coding: utf-8
 #
-#  Copyright (c) 2008—2012 Andy Mikhailenko
+#  Copyright (c) 2008—2014 Andy Mikhailenko
 #
 #  This file is part of django-autoslug.
 #
@@ -58,7 +58,7 @@ def generate_unique_slug(field, instance, slug, manager):
     index = 1
 
     if not manager:
-        manager = type(instance).objects
+        manager = field.model._default_manager
 
 
     # keep changing the slug until it is unique
